@@ -18,31 +18,33 @@
  *)
 
 open Js_of_ocaml
-
 include Eliom_parameter_sigs.S with type raw_post_data = unit
 
+val user_type
+  :  of_string:(string -> 'a)
+  -> to_string:('a -> string)
+  -> string
+  -> ('a, [`WithoutSuffix], [`One of 'a] param_name) params_type
 (** Specifying parameter as [user_type ~of_string ~to_string s] tells
     that the service take a parameter, labeled [s], and that the
     server will have to use [of_string] and [to_string] to make the
     conversion between the OCaml representation of the parameter and
     it's external representation as a string. It allows one to use
     whatever type you want for a parameter of the service.  *)
-val user_type :
-  of_string:(string -> 'a) ->
-  to_string:('a -> string) ->
-  string ->
-  ('a, [ `WithoutSuffix ], [ `One of 'a ] param_name) params_type
 
+val all_suffix_user
+  :  of_string:(string -> 'a)
+  -> to_string:('a -> string)
+  -> string
+  -> ('a, [`Endsuffix], [`One of 'a] param_name) params_type
 (** Takes the whole suffix, as long as possible, with a type specified
     by the user. *)
-val all_suffix_user :
-  of_string:(string -> 'a) ->
-  to_string:('a -> string) -> string ->
-  ('a, [ `Endsuffix ], [` One of 'a ] param_name) params_type
 
-val reconstruct_params_form :
-  (string * Form.form_elt) list -> ('a, _, _) params_type -> 'a option
+val reconstruct_params_form
+  :  (string * Form.form_elt) list
+  -> ('a, _, _) params_type
+  -> 'a option
 
-val get_non_localized_get_parameters :
-  ('a, [ `WithoutSuffix ], 'b) non_localized_params ->
-  'a option
+val get_non_localized_get_parameters
+  :  ('a, [`WithoutSuffix], 'b) non_localized_params
+  -> 'a option
