@@ -26,77 +26,90 @@
     for details. *)
 
 type 'a kind
+type browser_content = [`Browser]
+type 'a application_content = [`Appl of 'a]
 
-type browser_content = [ `Browser ]
-type 'a application_content = [ `Appl of 'a ]
+module Html :
+  Eliom_registration_sigs.S
+    with type page = Html_types.html Eliom_content.Html.elt
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
-module Html : Eliom_registration_sigs.S
-  with type page = Html_types.html Eliom_content.Html.elt
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module Action :
+  Eliom_registration_sigs.S
+    with type page = unit
+     and type options = [`Reload | `NoReload]
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
-module Action : Eliom_registration_sigs.S
-  with type page = unit
-   and type options = [ `Reload | `NoReload ]
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
-
-module Unit : Eliom_registration_sigs.S
-  with type page = unit
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module Unit :
+  Eliom_registration_sigs.S
+    with type page = unit
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
+type appl_service_options = {do_not_launch : bool}
 (** Has no effect on client; for compatibility with server *)
-type appl_service_options = { do_not_launch : bool }
 
 module App (P : Eliom_registration_sigs.APP_PARAM) : sig
-
   val application_name : string
 
   type app_id
 
-  include Eliom_registration_sigs.S
-    with type page = Html_types.html Eliom_content.Html.elt
-     and type options = appl_service_options
-     and type return = Eliom_service.non_ocaml
-     and type result = app_id application_content kind
-
+  include
+    Eliom_registration_sigs.S
+      with type page = Html_types.html Eliom_content.Html.elt
+       and type options = appl_service_options
+       and type return = Eliom_service.non_ocaml
+       and type result = app_id application_content kind
 end
 
 type _ redirection =
-    Redirection :
-      (unit, unit, Eliom_service.get , _, _, _, _,
-       [ `WithoutSuffix ], unit, unit, 'a) Eliom_service.t ->
-    'a redirection
+  | Redirection :
+      ( unit
+      , unit
+      , Eliom_service.get
+      , _
+      , _
+      , _
+      , _
+      , [`WithoutSuffix]
+      , unit
+      , unit
+      , 'a )
+      Eliom_service.t
+      -> 'a redirection
 
 (* [page] et al. are not really polymorphic. The type variables are
     necessary for maintaining type-level compatibility with server
     (for injections) *)
-module Redirection : Eliom_registration_sigs.S_poly_with_send
-  with type 'a page = Eliom_service.non_ocaml redirection
-   and type options =
-         [ `MovedPermanently
-         | `Found
-         | `SeeOther
-         | `NotNodifed
-         | `UseProxy
-         | `TemporaryRedirect ]
-   and type 'a return = Eliom_service.non_ocaml
-   and type 'a result = browser_content kind
+module Redirection :
+  Eliom_registration_sigs.S_poly_with_send
+    with type 'a page = Eliom_service.non_ocaml redirection
+     and type options =
+          [ `MovedPermanently
+          | `Found
+          | `SeeOther
+          | `NotNodifed
+          | `UseProxy
+          | `TemporaryRedirect ]
+     and type 'a return = Eliom_service.non_ocaml
+     and type 'a result = browser_content kind
 
-module Any : Eliom_registration_sigs.S_poly_with_send
-  with type 'a page = 'a kind
-   and type options = unit
-   and type 'a return = Eliom_service.non_ocaml
-   and type 'a result = 'a kind
+module Any :
+  Eliom_registration_sigs.S_poly_with_send
+    with type 'a page = 'a kind
+     and type options = unit
+     and type 'a return = Eliom_service.non_ocaml
+     and type 'a result = 'a kind
 
+val appl_self_redirect
+  :  ('page -> [< 'a application_content | browser_content] kind Lwt.t)
+  -> 'page
+  -> 'appl application_content kind Lwt.t
 (** For compatibility with server-side [appl_self_redirect] *)
-val appl_self_redirect :
-  ('page -> [< 'a application_content | browser_content ] kind Lwt.t) ->
-  'page ->
-  'appl application_content kind Lwt.t
 
 (**/**)
 
