@@ -31,6 +31,7 @@
 
     {2 Type definitions} *)
 
+type 'a kind
 (** The type [kind] is an abstract type for the HTTP frame returned by
     a service. The type parameter indicates the content type, and is
     one of the following types:
@@ -39,61 +40,62 @@
         {- {!block_content}}
         {- {!unknown_content}}
         {- {!ocaml_content}}} *)
-type 'a kind
 
 (** {3 Return types for {!type:Eliom_service.service} }
 
     {4 Classical content} *)
 
+type browser_content = [`Browser]
 (** The type [browser_content] is to be used as a phantom type
     parameter for {!Eliom_registration.kind}. It means the returned
     content must be interpreted in the browser as stated by the
     content-type header. This is most common return type for an eliom
     service, see for example {!Html}, {!CssText}, {!File},
     {!Redirection}. *)
-type browser_content = [ `Browser ]
 
+type block_content
 (** The type [block_content] is to be used as a phantom type parameter
     for {!Eliom_registration.kind}. It means the returned content is a
     subtree of an XML value. See for example {!Block5} or
     {!Make_typed_xml_registration}. *)
-type block_content
 
+type unknown_content
 (** The type [unknown_content] is to be used as a phantom type
     parameter for {!Eliom_registration.kind} when the content-type
     can't be determined statically. See {!Text} or {!Any}. *)
-type unknown_content
 
 (** {4 Application content} *)
 
+type 'a application_content = [`Appl of 'a]
 (** The type [application_content] is a refinement of {!appl_service}
     to be used as a phantom type parameters for
     {!Eliom_registration.kind}. The parameter ['a] is phantom type
     that is unique for a given application. *)
-type 'a application_content = [ `Appl of 'a ]
 
-(** Typed application name *)
 type 'a application_name
+(** Typed application name *)
 
 (** {4 OCaml content} *)
 
+type 'a ocaml_content
 (** The type [ocaml_content] is an synomyn for
     {!Eliom_service.ocaml_service} to be used as a phantom type
     parameters for {!Eliom_registration.kind}. See {!Ocaml}. *)
-type 'a ocaml_content
 
 (** {2 Using HTML with services } *)
 
 (** Eliom service registration for services that return HTML
     pages. *)
-module Html : Eliom_registration_sigs.S_with_create
-  with type page = Html_types.html Eliom_content.Html.elt
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module Html :
+  Eliom_registration_sigs.S_with_create
+    with type page = Html_types.html Eliom_content.Html.elt
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
 (** {2 Eliom client/server applications} *)
 
+type appl_service_options = {do_not_launch : bool}
 (** Type for the options of an Eliom application service.
 
     If you set [do_not_launch] to [true] when creating an application
@@ -102,22 +104,23 @@ module Html : Eliom_registration_sigs.S_with_create
     side process won't be stopped. Use this if some of your pages are
     not using the client side program and you want to make them load
     faster. *)
-type appl_service_options = { do_not_launch : bool }
 
+val default_appl_service_options : appl_service_options
 (** The default options record for an eliom service. See
     {!appl_service_options}. *)
-val default_appl_service_options : appl_service_options
 
 module type APP = sig
-
+  val application_script
+    :  ?defer:bool
+    -> ?async:bool
+    -> unit
+    -> [> `Script] Eliom_content.Html.elt
   (** The function [application_name ()] returns a [<script>] node
       that represents the javascript part of the application. If you
       do not include this script in the [<head>] node of your page, it
       will be automatically added at the end of the [<head>] node. *)
-  val application_script :
-    ?defer:bool -> ?async:bool -> unit ->
-    [> `Script ] Eliom_content.Html.elt
 
+  val application_name : string
   (** Unique identifier for this application. Currently, it is just
       the application name as defined by
       {!Appl_params.application_name}.
@@ -125,30 +128,31 @@ module type APP = sig
       {e Warning: do not mix up with the "application instance id",
       that is unique for each instance of the application on a
       client.}  *)
-  val application_name : string
 
+  val is_initial_request : unit -> bool
   (** Checks during a request whether it is the initial request of the
       client process in this Eliom application. *)
-  val is_initial_request : unit -> bool
 
+  type app_id
   (** The type [appl] is an abstract type for identifying an
       application. It usually used a phantom parameter for
       {!application_content}. *)
-  type app_id
 
-  include Eliom_registration_sigs.S_with_create
-    with type page = Html_types.html Eliom_content.Html.elt
-     and type options = appl_service_options
-     and type return = Eliom_service.non_ocaml
-     and type result = app_id application_content kind
+  include
+    Eliom_registration_sigs.S_with_create
+      with type page = Html_types.html Eliom_content.Html.elt
+       and type options = appl_service_options
+       and type return = Eliom_service.non_ocaml
+       and type result = app_id application_content kind
 
   (**/**)
-  val typed_name : app_id application_name
 
+  val typed_name : app_id application_name
 end
 
+val transform_global_app_uri
+  : (Eliom_content.Html.uri -> Eliom_content.Html.uri) ref
 (** Function to modify the global_app URI for some obscure reason *)
-val transform_global_app_uri : (Eliom_content.Html.uri -> Eliom_content.Html.uri) ref
 
 (** Functor for application creation.
     See {% <<a_manual chapter="clientserver-applications" | the chapter on applications >> %}
@@ -157,17 +161,18 @@ module App (App_params : Eliom_registration_sigs.APP_PARAM) : APP
 
 module type TMPL_PARAMS = sig
   type t
-  val name: string
-  val make_page: t -> Html_types.html Eliom_content.Html.elt Lwt.t
-  val update: t -> unit Eliom_client_value.t
+
+  val name : string
+  val make_page : t -> Html_types.html Eliom_content.Html.elt Lwt.t
+  val update : t -> unit Eliom_client_value.t
 end
 
-module Eliom_tmpl (App : APP) (Tmpl_param : TMPL_PARAMS):
+module Eliom_tmpl (App : APP) (Tmpl_param : TMPL_PARAMS) :
   Eliom_registration_sigs.S_with_create
-  with type page = Tmpl_param.t
-   and type options = appl_service_options
-   and type return = Eliom_service.non_ocaml
-   and type result = App.app_id application_content kind
+    with type page = Tmpl_param.t
+     and type options = appl_service_options
+     and type return = Eliom_service.non_ocaml
+     and type result = App.app_id application_content kind
 
 (** {3 Services returning HTML (or other TyXML) fragments} *)
 
@@ -176,11 +181,12 @@ module Eliom_tmpl (App : APP) (Tmpl_param : TMPL_PARAMS):
 
     For Eliom application, prefers {!Ocaml} services to send page
     fragments. *)
-module Flow5 : Eliom_registration_sigs.S_with_create
-  with type page = Html_types.flow5 Eliom_content.Html.elt list
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = block_content kind
+module Flow5 :
+  Eliom_registration_sigs.S_with_create
+    with type page = Html_types.flow5 Eliom_content.Html.elt list
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = block_content kind
 
 (*
 (** Eliom service registration for services that return fragments of
@@ -201,21 +207,23 @@ module Make_typed_xml_registration
 (** Eliom service registration and forms creation for untyped HTML
     page. The page content is a [string] that must contains valid HTML
     and the content type is always [text/html]. *)
-module Html_text : Eliom_registration_sigs.S_with_create
-  with type page = string
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module Html_text :
+  Eliom_registration_sigs.S_with_create
+    with type page = string
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
 (** Eliom service registration for services that returns CSS. The page
     content is a [string] that must contains valid CSS and the content
     type is always [text/css]. The option is the optional
     "Cache-policy: max-age" header value to be sent. *)
-module CssText : Eliom_registration_sigs.S_with_create
-  with type page = string
-   and type options = int
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module CssText :
+  Eliom_registration_sigs.S_with_create
+    with type page = string
+     and type options = int
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
 (** {2 Other kinds of services} *)
 
@@ -227,25 +235,37 @@ module CssText : Eliom_registration_sigs.S_with_create
     If you give the optional parameter [~options:`NoReload] to the
     registration function, the action will executed and a [204 No
     Content] will be sent to the server. *)
-module Action : Eliom_registration_sigs.S_with_create
-  with type return = Eliom_service.non_ocaml
-   and type page = unit
-   and type options = [ `Reload | `NoReload ]
-   and type result = browser_content kind
+module Action :
+  Eliom_registration_sigs.S_with_create
+    with type return = Eliom_service.non_ocaml
+     and type page = unit
+     and type options = [`Reload | `NoReload]
+     and type result = browser_content kind
 
 (** Similar to {!Actions} with [`NoReload] option. *)
-module Unit : Eliom_registration_sigs.S_with_create
-  with type page = unit
-   and type options = unit
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module Unit :
+  Eliom_registration_sigs.S_with_create
+    with type page = unit
+     and type options = unit
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
 (** Auxiliarry type to hide non-interesting type parameters *)
 type _ redirection =
-    Redirection :
-      (unit, unit, Eliom_service.get , _, _, _, _,
-       [ `WithoutSuffix ], unit, unit, 'a) Eliom_service.t ->
-    'a redirection
+  | Redirection :
+      ( unit
+      , unit
+      , Eliom_service.get
+      , _
+      , _
+      , _
+      , _
+      , [`WithoutSuffix]
+      , unit
+      , unit
+      , 'a )
+      Eliom_service.t
+      -> 'a redirection
 
 (** Eliom service registration for services that returns a
     redirections towards another service. See the Eliom manual for
@@ -262,28 +282,27 @@ type _ redirection =
     - [`UseProxy] to return [305 Use Proxy].
     - [`TemporaryRedirect] to return [307 Temporary Redirect]. *)
 module Redirection : sig
+  include
+    Eliom_registration_sigs.S_poly_with_create
+      with type 'a page = 'a redirection
+       and type options =
+            [ `MovedPermanently
+            | `Found
+            | `SeeOther
+            | `NotNodifed
+            | `UseProxy
+            | `TemporaryRedirect ]
+       and type 'a return = 'a
 
-  include Eliom_registration_sigs.S_poly_with_create
-    with type 'a page = 'a redirection
-     and type options =
-           [ `MovedPermanently
-           | `Found
-           | `SeeOther
-           | `NotNodifed
-           | `UseProxy
-           | `TemporaryRedirect ]
-     and type 'a return = 'a
-
+  val send
+    :  ?options:options
+    -> ?charset:string
+    -> ?code:int
+    -> ?content_type:string
+    -> ?headers:Ocsigen_header.t
+    -> _ page
+    -> _ kind Lwt.t
   (** More polymorphic version of {!Eliom_registration_sigs.send} *)
-  val send :
-    ?options      : options ->
-    ?charset      : string ->
-    ?code         : int ->
-    ?content_type : string ->
-    ?headers      : Ocsigen_header.t ->
-    _ page ->
-    _ kind Lwt.t
-
 end
 
 (** Eliom service registration for services that returns a
@@ -295,17 +314,18 @@ end
     The default returned HTTP code is [302 Found]. You could use the
     optional parameter [~options] to change this value, see
     {!Redirections} for a detailed description. *)
-module String_redirection : Eliom_registration_sigs.S_with_create
-  with type page = Eliom_lib.Url.uri
-   and type options =
-         [ `MovedPermanently
-         | `Found
-         | `SeeOther
-         | `NotNodifed
-         | `UseProxy
-         | `TemporaryRedirect ]
-   and type return = Eliom_service.non_ocaml
-   and type result = browser_content kind
+module String_redirection :
+  Eliom_registration_sigs.S_with_create
+    with type page = Eliom_lib.Url.uri
+     and type options =
+          [ `MovedPermanently
+          | `Found
+          | `SeeOther
+          | `NotNodifed
+          | `UseProxy
+          | `TemporaryRedirect ]
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 
 (** Eliom service registration for services that returns file
     contents. The value returned by service handlers is the name of
@@ -314,45 +334,44 @@ module String_redirection : Eliom_registration_sigs.S_with_create
     send files with Eliom>>%}.  The option is the optional
     "Cache-policy: max-age" header value to be sent. *)
 module File : sig
-
+  val check_file : string -> bool
   (** The function [check_file file] is true if [File.send file] would
       effectively return the file (i.e. the file is present and
       readable) *)
-  val check_file : string -> bool
-
-  include Eliom_registration_sigs.S_with_create
-    with type page = string
-     and type options = int
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
 
+  include
+    Eliom_registration_sigs.S_with_create
+      with type page = string
+       and type options = int
+       and type return = Eliom_service.non_ocaml
+       and type result = browser_content kind
 end
 
 (** Same as file but makes possible to specify the content type for
     each file. The value returned by service handlers is a pair
     [(file_name, content_type)]. *)
 module File_ct : sig
-
+  val check_file : string -> bool
   (** The function [check_file file] is true if [File.send file] would
       effectively return the file (i.e. the file is present and
       readable) *)
-  val check_file : string -> bool
-
-  include Eliom_registration_sigs.S_with_create
-    with type page = string * string
-     and type options = int
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
 
+  include
+    Eliom_registration_sigs.S_with_create
+      with type page = string * string
+       and type options = int
+       and type return = Eliom_service.non_ocaml
+       and type result = browser_content kind
 end
 
 (** Eliom service registration for services that send marshalled OCaml
     values. *)
-module Ocaml : Eliom_registration_sigs.S_poly_with_create_with_send
-  with type 'a page = 'a
-   and type options = unit
-   and type 'a return = 'a Eliom_service.ocaml
-   and type 'a result = 'a ocaml_content kind
+module Ocaml :
+  Eliom_registration_sigs.S_poly_with_create_with_send
+    with type 'a page = 'a
+     and type options = unit
+     and type 'a return = 'a Eliom_service.ocaml
+     and type 'a result = 'a ocaml_content kind
 
 (** Eliom service registration for services that choose dynamically
     what they want to send. The content is created using for example
@@ -360,12 +379,17 @@ module Ocaml : Eliom_registration_sigs.S_poly_with_create_with_send
     for more information about {% <<a_manual chapter="server-outputs"
     fragment="any"|services that choose dynamically what they want to
     send>>%} *)
-module Any :  Eliom_registration_sigs.S_poly_with_create_with_send
-  with type 'a page = 'a kind
-   and type options = unit
-   and type 'a return = Eliom_service.non_ocaml
-   and type 'a result = 'a kind
+module Any :
+  Eliom_registration_sigs.S_poly_with_create_with_send
+    with type 'a page = 'a kind
+     and type options = unit
+     and type 'a return = Eliom_service.non_ocaml
+     and type 'a result = 'a kind
 
+val appl_self_redirect
+  :  ('page -> [< 'a application_content | browser_content] kind Lwt.t)
+  -> 'page
+  -> 'appl application_content kind Lwt.t
 (** The function [appl_self_redirect send page] is an helper function
     required for defining {!Any} service usable inside an Eliom
     application ({!App}). It allows casting an Eliom senders that do
@@ -378,21 +402,18 @@ module Any :  Eliom_registration_sigs.S_poly_with_create_with_send
     application). Hence, the service may be called two times in a row
     and you should not use this function for services that use POST
     parameters. *)
-val appl_self_redirect :
-  ('page -> [< 'a application_content | browser_content ] kind Lwt.t) ->
-  'page ->
-  'appl application_content kind Lwt.t
 
 (** Eliom service registration for services that returns "byte"-string
     contents. The page content is a pair [(raw_content,
     content_type)]. See also {!Streamlist} for another kind of service
     that returns "byte" contents. The option is the optional
     "Cache-policy: max-age" header value to be sent. *)
-module String : Eliom_registration_sigs.S_with_create
-  with type page = string * string
-   and type options = int
-   and type return = Eliom_service.non_ocaml
-   and type result = unknown_content kind
+module String :
+  Eliom_registration_sigs.S_with_create
+    with type page = string * string
+     and type options = int
+     and type return = Eliom_service.non_ocaml
+     and type result = unknown_content kind
 
 (*
 (** Eliom service registration for services that returns "byte"
@@ -421,16 +442,20 @@ module Streamlist : Eliom_registration_sigs.S_with_create
     <<a_manual project="tutorial" chapter="interaction"| Eliom
     tutorial>>%} for example. *)
 module Customize
-    (R : Eliom_registration_sigs.S_with_create)
-    (T : sig type page val translate : page -> R.page Lwt.t end) :
+    (R : Eliom_registration_sigs.S_with_create) (T : sig
+      type page
+
+      val translate : page -> R.page Lwt.t
+    end) :
   Eliom_registration_sigs.S_with_create
-  with type options = R.options
-   and type return = R.return
-   and type page = T.page
-   and type result = R.result
+    with type options = R.options
+     and type return = R.return
+     and type page = T.page
+     and type result = R.result
 
 (** {2 Using your own error pages} *)
 
+val set_exn_handler : (exn -> browser_content kind Lwt.t) -> unit
 (** The [set_exn_handler handler] allows redefinition of error pages:
     [404] or any exception during page generation.
 
@@ -450,20 +475,17 @@ module Customize
     {!Eliom_service.register_eliom_module}. Otherwise you will also
     get this exception.}
 *)
-val set_exn_handler : (exn -> browser_content kind Lwt.t) -> unit
 
 (** {2 Unsafe cast of contents} *)
 
+val cast_unknown_content_kind : unknown_content kind -> 'a kind
 (** If you know that the content you generated using [Text.send] or
     [Streamlist.send] is the same as some other kind, you can cast it
     with [cast_unknown_content_kind] for use with [Any] module.*)
-val cast_unknown_content_kind :
-  unknown_content kind -> 'a kind
 
+val cast_http_result : Ocsigen_response.t -> 'a kind
 (** [cast_http_result] should only be used to register new output
     modules *)
-val cast_http_result : Ocsigen_response.t -> 'a kind
 
 val extension : Ocsigen_server.Site.extension
-
 val end_init : unit -> unit
