@@ -18,22 +18,31 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *)
 
-val close_persistent_state2 :
-  scope:Eliom_common.user_scope ->
-  Eliom_common.sitedata ->
-  Eliom_common.perssessgrp option -> string -> unit Lwt.t
-val close_persistent_state :
-  scope:[< Eliom_common.user_scope ] ->
-  secure_o:bool option ->
-  ?sp:Eliom_common.server_params -> unit -> unit Lwt.t
-val find_or_create_persistent_cookie :
-  ?set_session_group:string ->
-  cookie_scope:[< Eliom_common.cookie_scope ] ->
-  secure_o:bool option ->
-  ?sp:Eliom_common.server_params ->
-  unit -> Eliom_common.one_persistent_cookie_info Lwt.t
-val find_persistent_cookie_only :
-  cookie_scope:[< Eliom_common.cookie_scope ] ->
-  secure_o:bool option ->
-  ?sp:Eliom_common.server_params ->
-  unit -> Eliom_common.one_persistent_cookie_info Lwt.t
+val close_persistent_state2
+  :  scope:Eliom_common.user_scope
+  -> Eliom_common.sitedata
+  -> Eliom_common.perssessgrp option
+  -> string
+  -> unit Lwt.t
+
+val close_persistent_state
+  :  scope:[< Eliom_common.user_scope]
+  -> secure_o:bool option
+  -> ?sp:Eliom_common.server_params
+  -> unit
+  -> unit Lwt.t
+
+val find_or_create_persistent_cookie
+  :  ?set_session_group:string
+  -> cookie_scope:[< Eliom_common.cookie_scope]
+  -> secure_o:bool option
+  -> ?sp:Eliom_common.server_params
+  -> unit
+  -> Eliom_common.one_persistent_cookie_info Lwt.t
+
+val find_persistent_cookie_only
+  :  cookie_scope:[< Eliom_common.cookie_scope]
+  -> secure_o:bool option
+  -> ?sp:Eliom_common.server_params
+  -> unit
+  -> Eliom_common.one_persistent_cookie_info Lwt.t
